# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetArtifactFileResult',
    'AwaitableGetArtifactFileResult',
    'get_artifact_file',
    'get_artifact_file_output',
]

@pulumi.output_type
class GetArtifactFileResult:
    """
    A collection of values returned by getArtifactFile.
    """
    def __init__(__self__, artifact_path=None, content=None, content_base64=None, id=None, job=None, max_size_bytes=None, project=None, ref=None):
        if artifact_path and not isinstance(artifact_path, str):
            raise TypeError("Expected argument 'artifact_path' to be a str")
        pulumi.set(__self__, "artifact_path", artifact_path)
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if content_base64 and not isinstance(content_base64, str):
            raise TypeError("Expected argument 'content_base64' to be a str")
        pulumi.set(__self__, "content_base64", content_base64)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if job and not isinstance(job, str):
            raise TypeError("Expected argument 'job' to be a str")
        pulumi.set(__self__, "job", job)
        if max_size_bytes and not isinstance(max_size_bytes, int):
            raise TypeError("Expected argument 'max_size_bytes' to be a int")
        pulumi.set(__self__, "max_size_bytes", max_size_bytes)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if ref and not isinstance(ref, str):
            raise TypeError("Expected argument 'ref' to be a str")
        pulumi.set(__self__, "ref", ref)

    @_builtins.property
    @pulumi.getter(name="artifactPath")
    def artifact_path(self) -> _builtins.str:
        """
        Path to the artifact file within the job's artifacts archive. This path is relative to the archive contents (not the local filesystem). Ensure each `get_artifact_file` data source in your configuration uses a unique artifact_path to avoid ambiguity.
        """
        return pulumi.get(self, "artifact_path")

    @_builtins.property
    @pulumi.getter
    def content(self) -> _builtins.str:
        """
        The content of the artifact file as a UTF-8 string. Use `content_base64` for binary files.
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter(name="contentBase64")
    def content_base64(self) -> _builtins.str:
        """
        The content of the artifact file as a base64-encoded string. Useful for binary files.
        """
        return pulumi.get(self, "content_base64")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this datasource. In the format `<project>:<ref>:<job>:<artifact_path>`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def job(self) -> _builtins.str:
        """
        The name of the job.
        """
        return pulumi.get(self, "job")

    @_builtins.property
    @pulumi.getter(name="maxSizeBytes")
    def max_size_bytes(self) -> Optional[_builtins.int]:
        """
        Maximum bytes to read from the artifact. Defaults to 10MB (10485760 bytes).
        """
        return pulumi.get(self, "max_size_bytes")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def ref(self) -> _builtins.str:
        """
        The name of the branch, tag, or commit SHA.
        """
        return pulumi.get(self, "ref")


class AwaitableGetArtifactFileResult(GetArtifactFileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetArtifactFileResult(
            artifact_path=self.artifact_path,
            content=self.content,
            content_base64=self.content_base64,
            id=self.id,
            job=self.job,
            max_size_bytes=self.max_size_bytes,
            project=self.project,
            ref=self.ref)


def get_artifact_file(artifact_path: Optional[_builtins.str] = None,
                      job: Optional[_builtins.str] = None,
                      max_size_bytes: Optional[_builtins.int] = None,
                      project: Optional[_builtins.str] = None,
                      ref: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetArtifactFileResult:
    """
    The `get_artifact_file` data source allows downloading a single artifact file from a specific job in the latest successful pipeline for a given reference (branch, tag, or commit).
    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/job_artifacts/#download-a-single-artifact-file-by-reference-name)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    # Download a text artifact file from the latest successful pipeline
    config = gitlab.get_artifact_file(project="namespace/myproject",
        job="build-job",
        ref="main",
        artifact_path="config/settings.json")
    pulumi.export("configContent", config.content)
    # Download a binary artifact file using base64 encoding
    binary = gitlab.get_artifact_file(project="namespace/myproject",
        job="build-job",
        ref="v1.0.0",
        artifact_path="dist/app.zip")
    pulumi.export("binaryContentBase64", binary.content_base64)
    # Download artifact from a specific tag
    release = gitlab.get_artifact_file(project="12345",
        job="release-job",
        ref="v2.1.0",
        artifact_path="release-notes.txt")
    # Download a larger artifact with custom size limit
    large_artifact = gitlab.get_artifact_file(project="namespace/myproject",
        job="build-job",
        ref="main",
        artifact_path="dist/large-file.zip",
        max_size_bytes=20971520)
    ```


    :param _builtins.str artifact_path: Path to the artifact file within the job's artifacts archive. This path is relative to the archive contents (not the local filesystem). Ensure each `get_artifact_file` data source in your configuration uses a unique artifact_path to avoid ambiguity.
    :param _builtins.str job: The name of the job.
    :param _builtins.int max_size_bytes: Maximum bytes to read from the artifact. Defaults to 10MB (10485760 bytes).
    :param _builtins.str project: The ID or URL-encoded path of the project.
    :param _builtins.str ref: The name of the branch, tag, or commit SHA.
    """
    __args__ = dict()
    __args__['artifactPath'] = artifact_path
    __args__['job'] = job
    __args__['maxSizeBytes'] = max_size_bytes
    __args__['project'] = project
    __args__['ref'] = ref
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getArtifactFile:getArtifactFile', __args__, opts=opts, typ=GetArtifactFileResult).value

    return AwaitableGetArtifactFileResult(
        artifact_path=pulumi.get(__ret__, 'artifact_path'),
        content=pulumi.get(__ret__, 'content'),
        content_base64=pulumi.get(__ret__, 'content_base64'),
        id=pulumi.get(__ret__, 'id'),
        job=pulumi.get(__ret__, 'job'),
        max_size_bytes=pulumi.get(__ret__, 'max_size_bytes'),
        project=pulumi.get(__ret__, 'project'),
        ref=pulumi.get(__ret__, 'ref'))
def get_artifact_file_output(artifact_path: Optional[pulumi.Input[_builtins.str]] = None,
                             job: Optional[pulumi.Input[_builtins.str]] = None,
                             max_size_bytes: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                             project: Optional[pulumi.Input[_builtins.str]] = None,
                             ref: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetArtifactFileResult]:
    """
    The `get_artifact_file` data source allows downloading a single artifact file from a specific job in the latest successful pipeline for a given reference (branch, tag, or commit).
    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/job_artifacts/#download-a-single-artifact-file-by-reference-name)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    # Download a text artifact file from the latest successful pipeline
    config = gitlab.get_artifact_file(project="namespace/myproject",
        job="build-job",
        ref="main",
        artifact_path="config/settings.json")
    pulumi.export("configContent", config.content)
    # Download a binary artifact file using base64 encoding
    binary = gitlab.get_artifact_file(project="namespace/myproject",
        job="build-job",
        ref="v1.0.0",
        artifact_path="dist/app.zip")
    pulumi.export("binaryContentBase64", binary.content_base64)
    # Download artifact from a specific tag
    release = gitlab.get_artifact_file(project="12345",
        job="release-job",
        ref="v2.1.0",
        artifact_path="release-notes.txt")
    # Download a larger artifact with custom size limit
    large_artifact = gitlab.get_artifact_file(project="namespace/myproject",
        job="build-job",
        ref="main",
        artifact_path="dist/large-file.zip",
        max_size_bytes=20971520)
    ```


    :param _builtins.str artifact_path: Path to the artifact file within the job's artifacts archive. This path is relative to the archive contents (not the local filesystem). Ensure each `get_artifact_file` data source in your configuration uses a unique artifact_path to avoid ambiguity.
    :param _builtins.str job: The name of the job.
    :param _builtins.int max_size_bytes: Maximum bytes to read from the artifact. Defaults to 10MB (10485760 bytes).
    :param _builtins.str project: The ID or URL-encoded path of the project.
    :param _builtins.str ref: The name of the branch, tag, or commit SHA.
    """
    __args__ = dict()
    __args__['artifactPath'] = artifact_path
    __args__['job'] = job
    __args__['maxSizeBytes'] = max_size_bytes
    __args__['project'] = project
    __args__['ref'] = ref
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getArtifactFile:getArtifactFile', __args__, opts=opts, typ=GetArtifactFileResult)
    return __ret__.apply(lambda __response__: GetArtifactFileResult(
        artifact_path=pulumi.get(__response__, 'artifact_path'),
        content=pulumi.get(__response__, 'content'),
        content_base64=pulumi.get(__response__, 'content_base64'),
        id=pulumi.get(__response__, 'id'),
        job=pulumi.get(__response__, 'job'),
        max_size_bytes=pulumi.get(__response__, 'max_size_bytes'),
        project=pulumi.get(__response__, 'project'),
        ref=pulumi.get(__response__, 'ref')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IntegrationRedmineArgs', 'IntegrationRedmine']

@pulumi.input_type
class IntegrationRedmineArgs:
    def __init__(__self__, *,
                 issues_url: pulumi.Input[_builtins.str],
                 new_issue_url: pulumi.Input[_builtins.str],
                 project: pulumi.Input[_builtins.str],
                 project_url: pulumi.Input[_builtins.str],
                 use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a IntegrationRedmine resource.
        :param pulumi.Input[_builtins.str] issues_url: The URL to the Redmine project issue to link to this GitLab project.
        :param pulumi.Input[_builtins.str] new_issue_url: The URL to use to create a new issue in the Redmine project linked to this GitLab project.
        :param pulumi.Input[_builtins.str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[_builtins.str] project_url: The URL to the Redmine project to link to this GitLab project.
        :param pulumi.Input[_builtins.bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        """
        pulumi.set(__self__, "issues_url", issues_url)
        pulumi.set(__self__, "new_issue_url", new_issue_url)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "project_url", project_url)
        if use_inherited_settings is not None:
            pulumi.set(__self__, "use_inherited_settings", use_inherited_settings)

    @_builtins.property
    @pulumi.getter(name="issuesUrl")
    def issues_url(self) -> pulumi.Input[_builtins.str]:
        """
        The URL to the Redmine project issue to link to this GitLab project.
        """
        return pulumi.get(self, "issues_url")

    @issues_url.setter
    def issues_url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "issues_url", value)

    @_builtins.property
    @pulumi.getter(name="newIssueUrl")
    def new_issue_url(self) -> pulumi.Input[_builtins.str]:
        """
        The URL to use to create a new issue in the Redmine project linked to this GitLab project.
        """
        return pulumi.get(self, "new_issue_url")

    @new_issue_url.setter
    def new_issue_url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "new_issue_url", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="projectUrl")
    def project_url(self) -> pulumi.Input[_builtins.str]:
        """
        The URL to the Redmine project to link to this GitLab project.
        """
        return pulumi.get(self, "project_url")

    @project_url.setter
    def project_url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_url", value)

    @_builtins.property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")

    @use_inherited_settings.setter
    def use_inherited_settings(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_inherited_settings", value)


@pulumi.input_type
class _IntegrationRedmineState:
    def __init__(__self__, *,
                 issues_url: Optional[pulumi.Input[_builtins.str]] = None,
                 new_issue_url: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_url: Optional[pulumi.Input[_builtins.str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering IntegrationRedmine resources.
        :param pulumi.Input[_builtins.str] issues_url: The URL to the Redmine project issue to link to this GitLab project.
        :param pulumi.Input[_builtins.str] new_issue_url: The URL to use to create a new issue in the Redmine project linked to this GitLab project.
        :param pulumi.Input[_builtins.str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[_builtins.str] project_url: The URL to the Redmine project to link to this GitLab project.
        :param pulumi.Input[_builtins.bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        """
        if issues_url is not None:
            pulumi.set(__self__, "issues_url", issues_url)
        if new_issue_url is not None:
            pulumi.set(__self__, "new_issue_url", new_issue_url)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_url is not None:
            pulumi.set(__self__, "project_url", project_url)
        if use_inherited_settings is not None:
            pulumi.set(__self__, "use_inherited_settings", use_inherited_settings)

    @_builtins.property
    @pulumi.getter(name="issuesUrl")
    def issues_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL to the Redmine project issue to link to this GitLab project.
        """
        return pulumi.get(self, "issues_url")

    @issues_url.setter
    def issues_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "issues_url", value)

    @_builtins.property
    @pulumi.getter(name="newIssueUrl")
    def new_issue_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL to use to create a new issue in the Redmine project linked to this GitLab project.
        """
        return pulumi.get(self, "new_issue_url")

    @new_issue_url.setter
    def new_issue_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "new_issue_url", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="projectUrl")
    def project_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL to the Redmine project to link to this GitLab project.
        """
        return pulumi.get(self, "project_url")

    @project_url.setter
    def project_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_url", value)

    @_builtins.property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")

    @use_inherited_settings.setter
    def use_inherited_settings(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_inherited_settings", value)


@pulumi.type_token("gitlab:index/integrationRedmine:IntegrationRedmine")
class IntegrationRedmine(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 issues_url: Optional[pulumi.Input[_builtins.str]] = None,
                 new_issue_url: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_url: Optional[pulumi.Input[_builtins.str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        The `IntegrationRedmine` resource manages the lifecycle of a project integration with Redmine.

        > This resource is deprecated and will be removed in 19.0. Use `ProjectIntegrationRedmine`instead.
        Using Redmine requires that GitLab internal issue tracking is disabled for the project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_integrations/#redmine)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        redmine = gitlab.IntegrationRedmine("redmine",
            project=awesome_project.id,
            new_issue_url="https://redmine.example.com/issue",
            project_url="https://redmine.example.com/project",
            issues_url="https://redmine.example.com/issue/:id")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_integration_redmine`. For example:

        terraform

        import {

          to = gitlab_integration_redmine.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/integrationRedmine:IntegrationRedmine You can import a gitlab_integration_redmine state using `<resource> <project_id>`:
        ```

        ```sh
        $ pulumi import gitlab:index/integrationRedmine:IntegrationRedmine redmine 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] issues_url: The URL to the Redmine project issue to link to this GitLab project.
        :param pulumi.Input[_builtins.str] new_issue_url: The URL to use to create a new issue in the Redmine project linked to this GitLab project.
        :param pulumi.Input[_builtins.str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[_builtins.str] project_url: The URL to the Redmine project to link to this GitLab project.
        :param pulumi.Input[_builtins.bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IntegrationRedmineArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `IntegrationRedmine` resource manages the lifecycle of a project integration with Redmine.

        > This resource is deprecated and will be removed in 19.0. Use `ProjectIntegrationRedmine`instead.
        Using Redmine requires that GitLab internal issue tracking is disabled for the project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_integrations/#redmine)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        redmine = gitlab.IntegrationRedmine("redmine",
            project=awesome_project.id,
            new_issue_url="https://redmine.example.com/issue",
            project_url="https://redmine.example.com/project",
            issues_url="https://redmine.example.com/issue/:id")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_integration_redmine`. For example:

        terraform

        import {

          to = gitlab_integration_redmine.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/integrationRedmine:IntegrationRedmine You can import a gitlab_integration_redmine state using `<resource> <project_id>`:
        ```

        ```sh
        $ pulumi import gitlab:index/integrationRedmine:IntegrationRedmine redmine 1
        ```

        :param str resource_name: The name of the resource.
        :param IntegrationRedmineArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IntegrationRedmineArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 issues_url: Optional[pulumi.Input[_builtins.str]] = None,
                 new_issue_url: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_url: Optional[pulumi.Input[_builtins.str]] = None,
                 use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IntegrationRedmineArgs.__new__(IntegrationRedmineArgs)

            if issues_url is None and not opts.urn:
                raise TypeError("Missing required property 'issues_url'")
            __props__.__dict__["issues_url"] = issues_url
            if new_issue_url is None and not opts.urn:
                raise TypeError("Missing required property 'new_issue_url'")
            __props__.__dict__["new_issue_url"] = new_issue_url
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if project_url is None and not opts.urn:
                raise TypeError("Missing required property 'project_url'")
            __props__.__dict__["project_url"] = project_url
            __props__.__dict__["use_inherited_settings"] = use_inherited_settings
        super(IntegrationRedmine, __self__).__init__(
            'gitlab:index/integrationRedmine:IntegrationRedmine',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            issues_url: Optional[pulumi.Input[_builtins.str]] = None,
            new_issue_url: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            project_url: Optional[pulumi.Input[_builtins.str]] = None,
            use_inherited_settings: Optional[pulumi.Input[_builtins.bool]] = None) -> 'IntegrationRedmine':
        """
        Get an existing IntegrationRedmine resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] issues_url: The URL to the Redmine project issue to link to this GitLab project.
        :param pulumi.Input[_builtins.str] new_issue_url: The URL to use to create a new issue in the Redmine project linked to this GitLab project.
        :param pulumi.Input[_builtins.str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[_builtins.str] project_url: The URL to the Redmine project to link to this GitLab project.
        :param pulumi.Input[_builtins.bool] use_inherited_settings: Indicates whether or not to inherit default settings. Defaults to false.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IntegrationRedmineState.__new__(_IntegrationRedmineState)

        __props__.__dict__["issues_url"] = issues_url
        __props__.__dict__["new_issue_url"] = new_issue_url
        __props__.__dict__["project"] = project
        __props__.__dict__["project_url"] = project_url
        __props__.__dict__["use_inherited_settings"] = use_inherited_settings
        return IntegrationRedmine(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="issuesUrl")
    def issues_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL to the Redmine project issue to link to this GitLab project.
        """
        return pulumi.get(self, "issues_url")

    @_builtins.property
    @pulumi.getter(name="newIssueUrl")
    def new_issue_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL to use to create a new issue in the Redmine project linked to this GitLab project.
        """
        return pulumi.get(self, "new_issue_url")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="projectUrl")
    def project_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL to the Redmine project to link to this GitLab project.
        """
        return pulumi.get(self, "project_url")

    @_builtins.property
    @pulumi.getter(name="useInheritedSettings")
    def use_inherited_settings(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether or not to inherit default settings. Defaults to false.
        """
        return pulumi.get(self, "use_inherited_settings")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectDeployTokenArgs', 'ProjectDeployToken']

@pulumi.input_type
class ProjectDeployTokenArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 scopes: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ProjectDeployToken resource.
        :param pulumi.Input[_builtins.str] project: The Id or full path of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: The scopes of the project deploy token. Valid values are: `read_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `read_package_registry`, `write_package_registry`
        :param pulumi.Input[_builtins.str] expires_at: Time the token expires in RFC3339 format. Not set by default.
        :param pulumi.Input[_builtins.str] name: A name to describe the deploy token with.
        :param pulumi.Input[_builtins.str] username: A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        :param pulumi.Input[_builtins.bool] validate_past_expiration_date: Wether to validate if the expiration date is in the future.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "scopes", scopes)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if validate_past_expiration_date is not None:
            pulumi.set(__self__, "validate_past_expiration_date", validate_past_expiration_date)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The Id or full path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The scopes of the project deploy token. Valid values are: `read_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `read_package_registry`, `write_package_registry`
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "scopes", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Time the token expires in RFC3339 format. Not set by default.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name to describe the deploy token with.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)

    @_builtins.property
    @pulumi.getter(name="validatePastExpirationDate")
    def validate_past_expiration_date(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Wether to validate if the expiration date is in the future.
        """
        return pulumi.get(self, "validate_past_expiration_date")

    @validate_past_expiration_date.setter
    def validate_past_expiration_date(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "validate_past_expiration_date", value)


@pulumi.input_type
class _ProjectDeployTokenState:
    def __init__(__self__, *,
                 expired: Optional[pulumi.Input[_builtins.bool]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 revoked: Optional[pulumi.Input[_builtins.bool]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ProjectDeployToken resources.
        :param pulumi.Input[_builtins.bool] expired: True if the token is expired.
        :param pulumi.Input[_builtins.str] expires_at: Time the token expires in RFC3339 format. Not set by default.
        :param pulumi.Input[_builtins.str] name: A name to describe the deploy token with.
        :param pulumi.Input[_builtins.str] project: The Id or full path of the project.
        :param pulumi.Input[_builtins.bool] revoked: True if the token is revoked.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: The scopes of the project deploy token. Valid values are: `read_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `read_package_registry`, `write_package_registry`
        :param pulumi.Input[_builtins.str] token: The secret token. This is only populated when creating a new deploy token. **Note**: The token is not available for imported resources.
        :param pulumi.Input[_builtins.str] username: A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        :param pulumi.Input[_builtins.bool] validate_past_expiration_date: Wether to validate if the expiration date is in the future.
        """
        if expired is not None:
            pulumi.set(__self__, "expired", expired)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if revoked is not None:
            pulumi.set(__self__, "revoked", revoked)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if validate_past_expiration_date is not None:
            pulumi.set(__self__, "validate_past_expiration_date", validate_past_expiration_date)

    @_builtins.property
    @pulumi.getter
    def expired(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True if the token is expired.
        """
        return pulumi.get(self, "expired")

    @expired.setter
    def expired(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "expired", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Time the token expires in RFC3339 format. Not set by default.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name to describe the deploy token with.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Id or full path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def revoked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True if the token is revoked.
        """
        return pulumi.get(self, "revoked")

    @revoked.setter
    def revoked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "revoked", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The scopes of the project deploy token. Valid values are: `read_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `read_package_registry`, `write_package_registry`
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "scopes", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The secret token. This is only populated when creating a new deploy token. **Note**: The token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)

    @_builtins.property
    @pulumi.getter(name="validatePastExpirationDate")
    def validate_past_expiration_date(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Wether to validate if the expiration date is in the future.
        """
        return pulumi.get(self, "validate_past_expiration_date")

    @validate_past_expiration_date.setter
    def validate_past_expiration_date(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "validate_past_expiration_date", value)


@pulumi.type_token("gitlab:index/projectDeployToken:ProjectDeployToken")
class ProjectDeployToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        The `ProjectDeployToken` resource allows you to manage the lifecycle of deploy tokens on a project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/deploy_tokens/#project-deploy-tokens)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab
        import pulumi_std as std

        # Example Usage
        example = gitlab.ProjectDeployToken("example",
            project="example/deploying",
            name="Example project deploy token",
            username="example-username",
            expires_at="2020-03-14T00:00:00.000Z",
            scopes=[
                "read_repository",
                "read_registry",
            ])
        example_two = gitlab.ProjectDeployToken("example-two",
            project="12345678",
            name="Example project deploy token expires in 24h",
            expires_at=std.timeadd(duration=std.timestamp().result,
                timestamp="24h").result,
            scopes=[
                "read_repository",
                "read_registry",
            ])
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_deploy_token`. For example:

        terraform

        import {

          to = gitlab_project_deploy_token.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab project deploy tokens can be imported using an id made up of `{project_id}:{deploy_token_id}`.

        ```sh
        $ pulumi import gitlab:index/projectDeployToken:ProjectDeployToken project_token 1:4
        ```

        Note: the `token` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] expires_at: Time the token expires in RFC3339 format. Not set by default.
        :param pulumi.Input[_builtins.str] name: A name to describe the deploy token with.
        :param pulumi.Input[_builtins.str] project: The Id or full path of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: The scopes of the project deploy token. Valid values are: `read_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `read_package_registry`, `write_package_registry`
        :param pulumi.Input[_builtins.str] username: A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        :param pulumi.Input[_builtins.bool] validate_past_expiration_date: Wether to validate if the expiration date is in the future.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectDeployTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectDeployToken` resource allows you to manage the lifecycle of deploy tokens on a project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/deploy_tokens/#project-deploy-tokens)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab
        import pulumi_std as std

        # Example Usage
        example = gitlab.ProjectDeployToken("example",
            project="example/deploying",
            name="Example project deploy token",
            username="example-username",
            expires_at="2020-03-14T00:00:00.000Z",
            scopes=[
                "read_repository",
                "read_registry",
            ])
        example_two = gitlab.ProjectDeployToken("example-two",
            project="12345678",
            name="Example project deploy token expires in 24h",
            expires_at=std.timeadd(duration=std.timestamp().result,
                timestamp="24h").result,
            scopes=[
                "read_repository",
                "read_registry",
            ])
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_deploy_token`. For example:

        terraform

        import {

          to = gitlab_project_deploy_token.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab project deploy tokens can be imported using an id made up of `{project_id}:{deploy_token_id}`.

        ```sh
        $ pulumi import gitlab:index/projectDeployToken:ProjectDeployToken project_token 1:4
        ```

        Note: the `token` resource attribute is not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param ProjectDeployTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectDeployTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectDeployTokenArgs.__new__(ProjectDeployTokenArgs)

            __props__.__dict__["expires_at"] = expires_at
            __props__.__dict__["name"] = name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if scopes is None and not opts.urn:
                raise TypeError("Missing required property 'scopes'")
            __props__.__dict__["scopes"] = scopes
            __props__.__dict__["username"] = username
            __props__.__dict__["validate_past_expiration_date"] = validate_past_expiration_date
            __props__.__dict__["expired"] = None
            __props__.__dict__["revoked"] = None
            __props__.__dict__["token"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectDeployToken, __self__).__init__(
            'gitlab:index/projectDeployToken:ProjectDeployToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            expired: Optional[pulumi.Input[_builtins.bool]] = None,
            expires_at: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            revoked: Optional[pulumi.Input[_builtins.bool]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            token: Optional[pulumi.Input[_builtins.str]] = None,
            username: Optional[pulumi.Input[_builtins.str]] = None,
            validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None) -> 'ProjectDeployToken':
        """
        Get an existing ProjectDeployToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] expired: True if the token is expired.
        :param pulumi.Input[_builtins.str] expires_at: Time the token expires in RFC3339 format. Not set by default.
        :param pulumi.Input[_builtins.str] name: A name to describe the deploy token with.
        :param pulumi.Input[_builtins.str] project: The Id or full path of the project.
        :param pulumi.Input[_builtins.bool] revoked: True if the token is revoked.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: The scopes of the project deploy token. Valid values are: `read_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `read_package_registry`, `write_package_registry`
        :param pulumi.Input[_builtins.str] token: The secret token. This is only populated when creating a new deploy token. **Note**: The token is not available for imported resources.
        :param pulumi.Input[_builtins.str] username: A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        :param pulumi.Input[_builtins.bool] validate_past_expiration_date: Wether to validate if the expiration date is in the future.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectDeployTokenState.__new__(_ProjectDeployTokenState)

        __props__.__dict__["expired"] = expired
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["revoked"] = revoked
        __props__.__dict__["scopes"] = scopes
        __props__.__dict__["token"] = token
        __props__.__dict__["username"] = username
        __props__.__dict__["validate_past_expiration_date"] = validate_past_expiration_date
        return ProjectDeployToken(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def expired(self) -> pulumi.Output[_builtins.bool]:
        """
        True if the token is expired.
        """
        return pulumi.get(self, "expired")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[_builtins.str]:
        """
        Time the token expires in RFC3339 format. Not set by default.
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A name to describe the deploy token with.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The Id or full path of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def revoked(self) -> pulumi.Output[_builtins.bool]:
        """
        True if the token is revoked.
        """
        return pulumi.get(self, "revoked")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The scopes of the project deploy token. Valid values are: `read_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `read_package_registry`, `write_package_registry`
        """
        return pulumi.get(self, "scopes")

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Output[_builtins.str]:
        """
        The secret token. This is only populated when creating a new deploy token. **Note**: The token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Output[_builtins.str]:
        """
        A username for the deploy token. Default is `gitlab+deploy-token-{n}`.
        """
        return pulumi.get(self, "username")

    @_builtins.property
    @pulumi.getter(name="validatePastExpirationDate")
    def validate_past_expiration_date(self) -> pulumi.Output[_builtins.bool]:
        """
        Wether to validate if the expiration date is in the future.
        """
        return pulumi.get(self, "validate_past_expiration_date")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupServiceAccountArgs', 'GroupServiceAccount']

@pulumi.input_type
class GroupServiceAccountArgs:
    def __init__(__self__, *,
                 group: pulumi.Input[_builtins.str],
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['GroupServiceAccountTimeoutsArgs']] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GroupServiceAccount resource.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group that the service account is created in. Must be a top level group.
        :param pulumi.Input[_builtins.str] email: User account email. If not specified, generates an email prepended with `service_account_group_`. Custom email addresses require confirmation before the account is active, unless the group has a matching verified domain.
        :param pulumi.Input[_builtins.str] name: The name of the user. If not specified, the default Service account user name is used.
        :param pulumi.Input[_builtins.str] username: The username of the user. If not specified, it’s automatically generated.
        """
        pulumi.set(__self__, "group", group)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the group that the service account is created in. Must be a top level group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User account email. If not specified, generates an email prepended with `service_account_group_`. Custom email addresses require confirmation before the account is active, unless the group has a matching verified domain.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user. If not specified, the default Service account user name is used.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['GroupServiceAccountTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['GroupServiceAccountTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username of the user. If not specified, it’s automatically generated.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _GroupServiceAccountState:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 service_account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input['GroupServiceAccountTimeoutsArgs']] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GroupServiceAccount resources.
        :param pulumi.Input[_builtins.str] email: User account email. If not specified, generates an email prepended with `service_account_group_`. Custom email addresses require confirmation before the account is active, unless the group has a matching verified domain.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group that the service account is created in. Must be a top level group.
        :param pulumi.Input[_builtins.str] name: The name of the user. If not specified, the default Service account user name is used.
        :param pulumi.Input[_builtins.str] service_account_id: The service account id.
        :param pulumi.Input[_builtins.str] username: The username of the user. If not specified, it’s automatically generated.
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service_account_id is not None:
            pulumi.set(__self__, "service_account_id", service_account_id)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User account email. If not specified, generates an email prepended with `service_account_group_`. Custom email addresses require confirmation before the account is active, unless the group has a matching verified domain.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the group that the service account is created in. Must be a top level group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user. If not specified, the default Service account user name is used.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service account id.
        """
        return pulumi.get(self, "service_account_id")

    @service_account_id.setter
    def service_account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_account_id", value)

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['GroupServiceAccountTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['GroupServiceAccountTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username of the user. If not specified, it’s automatically generated.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("gitlab:index/groupServiceAccount:GroupServiceAccount")
class GroupServiceAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['GroupServiceAccountTimeoutsArgs', 'GroupServiceAccountTimeoutsArgsDict']]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `GroupServiceAccount` resource allows creating a GitLab group service account.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/service_accounts/#group-service-accounts)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # This must be a top-level group
        example = gitlab.Group("example",
            name="example",
            path="example",
            description="An example group")
        # The service account against the top-level group
        example_sa = gitlab.GroupServiceAccount("example_sa",
            group=example.id,
            name="example-name",
            username="example-username")
        # Group to assign the service account to. Can be the same top-level group resource as above, or a subgroup of that group.
        example_subgroup = gitlab.Group("example_subgroup",
            name="subgroup",
            path="example/subgroup",
            description="An example subgroup")
        # To assign the service account to a group
        example_membership = gitlab.GroupMembership("example_membership",
            group_id=example_subgroup.id,
            user_id=example_sa.service_account_id,
            access_level="developer",
            expires_at="2020-03-14")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_service_account`. For example:

        terraform

        import {

          to = gitlab_group_service_account.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/groupServiceAccount:GroupServiceAccount You can import a group service account using `<resource> <id>`. The
        ```

        `id` is in the form of <group_id>:<service_account_id>

        ```sh
        $ pulumi import gitlab:index/groupServiceAccount:GroupServiceAccount example example
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] email: User account email. If not specified, generates an email prepended with `service_account_group_`. Custom email addresses require confirmation before the account is active, unless the group has a matching verified domain.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group that the service account is created in. Must be a top level group.
        :param pulumi.Input[_builtins.str] name: The name of the user. If not specified, the default Service account user name is used.
        :param pulumi.Input[_builtins.str] username: The username of the user. If not specified, it’s automatically generated.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupServiceAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `GroupServiceAccount` resource allows creating a GitLab group service account.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/service_accounts/#group-service-accounts)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # This must be a top-level group
        example = gitlab.Group("example",
            name="example",
            path="example",
            description="An example group")
        # The service account against the top-level group
        example_sa = gitlab.GroupServiceAccount("example_sa",
            group=example.id,
            name="example-name",
            username="example-username")
        # Group to assign the service account to. Can be the same top-level group resource as above, or a subgroup of that group.
        example_subgroup = gitlab.Group("example_subgroup",
            name="subgroup",
            path="example/subgroup",
            description="An example subgroup")
        # To assign the service account to a group
        example_membership = gitlab.GroupMembership("example_membership",
            group_id=example_subgroup.id,
            user_id=example_sa.service_account_id,
            access_level="developer",
            expires_at="2020-03-14")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_service_account`. For example:

        terraform

        import {

          to = gitlab_group_service_account.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/groupServiceAccount:GroupServiceAccount You can import a group service account using `<resource> <id>`. The
        ```

        `id` is in the form of <group_id>:<service_account_id>

        ```sh
        $ pulumi import gitlab:index/groupServiceAccount:GroupServiceAccount example example
        ```

        :param str resource_name: The name of the resource.
        :param GroupServiceAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupServiceAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 timeouts: Optional[pulumi.Input[Union['GroupServiceAccountTimeoutsArgs', 'GroupServiceAccountTimeoutsArgsDict']]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupServiceAccountArgs.__new__(GroupServiceAccountArgs)

            __props__.__dict__["email"] = email
            if group is None and not opts.urn:
                raise TypeError("Missing required property 'group'")
            __props__.__dict__["group"] = group
            __props__.__dict__["name"] = name
            __props__.__dict__["timeouts"] = timeouts
            __props__.__dict__["username"] = username
            __props__.__dict__["service_account_id"] = None
        super(GroupServiceAccount, __self__).__init__(
            'gitlab:index/groupServiceAccount:GroupServiceAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            email: Optional[pulumi.Input[_builtins.str]] = None,
            group: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            service_account_id: Optional[pulumi.Input[_builtins.str]] = None,
            timeouts: Optional[pulumi.Input[Union['GroupServiceAccountTimeoutsArgs', 'GroupServiceAccountTimeoutsArgsDict']]] = None,
            username: Optional[pulumi.Input[_builtins.str]] = None) -> 'GroupServiceAccount':
        """
        Get an existing GroupServiceAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] email: User account email. If not specified, generates an email prepended with `service_account_group_`. Custom email addresses require confirmation before the account is active, unless the group has a matching verified domain.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group that the service account is created in. Must be a top level group.
        :param pulumi.Input[_builtins.str] name: The name of the user. If not specified, the default Service account user name is used.
        :param pulumi.Input[_builtins.str] service_account_id: The service account id.
        :param pulumi.Input[_builtins.str] username: The username of the user. If not specified, it’s automatically generated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupServiceAccountState.__new__(_GroupServiceAccountState)

        __props__.__dict__["email"] = email
        __props__.__dict__["group"] = group
        __props__.__dict__["name"] = name
        __props__.__dict__["service_account_id"] = service_account_id
        __props__.__dict__["timeouts"] = timeouts
        __props__.__dict__["username"] = username
        return GroupServiceAccount(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Output[_builtins.str]:
        """
        User account email. If not specified, generates an email prepended with `service_account_group_`. Custom email addresses require confirmation before the account is active, unless the group has a matching verified domain.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the group that the service account is created in. Must be a top level group.
        """
        return pulumi.get(self, "group")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the user. If not specified, the default Service account user name is used.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The service account id.
        """
        return pulumi.get(self, "service_account_id")

    @_builtins.property
    @pulumi.getter
    def timeouts(self) -> pulumi.Output[Optional['outputs.GroupServiceAccountTimeouts']]:
        return pulumi.get(self, "timeouts")

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The username of the user. If not specified, it’s automatically generated.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectPullMirrorArgs', 'ProjectPullMirror']

@pulumi.input_type
class ProjectPullMirrorArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 url: pulumi.Input[_builtins.str],
                 auth_password: Optional[pulumi.Input[_builtins.str]] = None,
                 auth_user: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror_overwrites_diverged_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_trigger_builds: Optional[pulumi.Input[_builtins.bool]] = None,
                 only_mirror_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ProjectPullMirror resource.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project owned by the authenticated user.
        :param pulumi.Input[_builtins.str] url: The URL of the remote repository to mirror from. While the API call allows including username and password as basic authentication in the URL, this resourcedoes not for security and idempotency reasons. Use `auth_user` and `auth_password` instead.
        :param pulumi.Input[_builtins.str] auth_password: Authentication password or token for the remote repository.
        :param pulumi.Input[_builtins.str] auth_user: Authentication username for the remote repository.
        :param pulumi.Input[_builtins.bool] enabled: Enable or disable the pull mirror. Defaults to `true`.
        :param pulumi.Input[_builtins.str] mirror_branch_regex: Regular expression for branches to mirror. Requires GitLab Premium or Ultimate. Cannot be used with `only_mirror_protected_branches`.
        :param pulumi.Input[_builtins.bool] mirror_overwrites_diverged_branches: Overwrite diverged branches on the target project.
        :param pulumi.Input[_builtins.bool] mirror_trigger_builds: Trigger CI/CD pipelines when the mirror updates.
        :param pulumi.Input[_builtins.bool] only_mirror_protected_branches: Mirror only protected branches. Cannot be used with `mirror_branch_regex`.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "url", url)
        if auth_password is not None:
            pulumi.set(__self__, "auth_password", auth_password)
        if auth_user is not None:
            pulumi.set(__self__, "auth_user", auth_user)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if mirror_branch_regex is not None:
            pulumi.set(__self__, "mirror_branch_regex", mirror_branch_regex)
        if mirror_overwrites_diverged_branches is not None:
            pulumi.set(__self__, "mirror_overwrites_diverged_branches", mirror_overwrites_diverged_branches)
        if mirror_trigger_builds is not None:
            pulumi.set(__self__, "mirror_trigger_builds", mirror_trigger_builds)
        if only_mirror_protected_branches is not None:
            pulumi.set(__self__, "only_mirror_protected_branches", only_mirror_protected_branches)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        The URL of the remote repository to mirror from. While the API call allows including username and password as basic authentication in the URL, this resourcedoes not for security and idempotency reasons. Use `auth_user` and `auth_password` instead.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="authPassword")
    def auth_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authentication password or token for the remote repository.
        """
        return pulumi.get(self, "auth_password")

    @auth_password.setter
    def auth_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_password", value)

    @_builtins.property
    @pulumi.getter(name="authUser")
    def auth_user(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authentication username for the remote repository.
        """
        return pulumi.get(self, "auth_user")

    @auth_user.setter
    def auth_user(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_user", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable the pull mirror. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="mirrorBranchRegex")
    def mirror_branch_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Regular expression for branches to mirror. Requires GitLab Premium or Ultimate. Cannot be used with `only_mirror_protected_branches`.
        """
        return pulumi.get(self, "mirror_branch_regex")

    @mirror_branch_regex.setter
    def mirror_branch_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mirror_branch_regex", value)

    @_builtins.property
    @pulumi.getter(name="mirrorOverwritesDivergedBranches")
    def mirror_overwrites_diverged_branches(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Overwrite diverged branches on the target project.
        """
        return pulumi.get(self, "mirror_overwrites_diverged_branches")

    @mirror_overwrites_diverged_branches.setter
    def mirror_overwrites_diverged_branches(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mirror_overwrites_diverged_branches", value)

    @_builtins.property
    @pulumi.getter(name="mirrorTriggerBuilds")
    def mirror_trigger_builds(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Trigger CI/CD pipelines when the mirror updates.
        """
        return pulumi.get(self, "mirror_trigger_builds")

    @mirror_trigger_builds.setter
    def mirror_trigger_builds(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mirror_trigger_builds", value)

    @_builtins.property
    @pulumi.getter(name="onlyMirrorProtectedBranches")
    def only_mirror_protected_branches(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Mirror only protected branches. Cannot be used with `mirror_branch_regex`.
        """
        return pulumi.get(self, "only_mirror_protected_branches")

    @only_mirror_protected_branches.setter
    def only_mirror_protected_branches(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "only_mirror_protected_branches", value)


@pulumi.input_type
class _ProjectPullMirrorState:
    def __init__(__self__, *,
                 auth_password: Optional[pulumi.Input[_builtins.str]] = None,
                 auth_user: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 last_error: Optional[pulumi.Input[_builtins.str]] = None,
                 last_successful_update_at: Optional[pulumi.Input[_builtins.str]] = None,
                 last_update_at: Optional[pulumi.Input[_builtins.str]] = None,
                 last_update_started_at: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror_id: Optional[pulumi.Input[_builtins.int]] = None,
                 mirror_overwrites_diverged_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_trigger_builds: Optional[pulumi.Input[_builtins.bool]] = None,
                 only_mirror_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 update_status: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectPullMirror resources.
        :param pulumi.Input[_builtins.str] auth_password: Authentication password or token for the remote repository.
        :param pulumi.Input[_builtins.str] auth_user: Authentication username for the remote repository.
        :param pulumi.Input[_builtins.bool] enabled: Enable or disable the pull mirror. Defaults to `true`.
        :param pulumi.Input[_builtins.str] last_error: Last error message from the mirror operation.
        :param pulumi.Input[_builtins.str] last_successful_update_at: Timestamp of the last successful mirror update.
        :param pulumi.Input[_builtins.str] last_update_at: Timestamp of the last mirror update attempt.
        :param pulumi.Input[_builtins.str] last_update_started_at: Timestamp when the last mirror update started.
        :param pulumi.Input[_builtins.str] mirror_branch_regex: Regular expression for branches to mirror. Requires GitLab Premium or Ultimate. Cannot be used with `only_mirror_protected_branches`.
        :param pulumi.Input[_builtins.int] mirror_id: The ID of the pull mirror. This ID is set by GitLab.
        :param pulumi.Input[_builtins.bool] mirror_overwrites_diverged_branches: Overwrite diverged branches on the target project.
        :param pulumi.Input[_builtins.bool] mirror_trigger_builds: Trigger CI/CD pipelines when the mirror updates.
        :param pulumi.Input[_builtins.bool] only_mirror_protected_branches: Mirror only protected branches. Cannot be used with `mirror_branch_regex`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project owned by the authenticated user.
        :param pulumi.Input[_builtins.str] update_status: Current status of the mirror update.
        :param pulumi.Input[_builtins.str] url: The URL of the remote repository to mirror from. While the API call allows including username and password as basic authentication in the URL, this resourcedoes not for security and idempotency reasons. Use `auth_user` and `auth_password` instead.
        """
        if auth_password is not None:
            pulumi.set(__self__, "auth_password", auth_password)
        if auth_user is not None:
            pulumi.set(__self__, "auth_user", auth_user)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if last_error is not None:
            pulumi.set(__self__, "last_error", last_error)
        if last_successful_update_at is not None:
            pulumi.set(__self__, "last_successful_update_at", last_successful_update_at)
        if last_update_at is not None:
            pulumi.set(__self__, "last_update_at", last_update_at)
        if last_update_started_at is not None:
            pulumi.set(__self__, "last_update_started_at", last_update_started_at)
        if mirror_branch_regex is not None:
            pulumi.set(__self__, "mirror_branch_regex", mirror_branch_regex)
        if mirror_id is not None:
            pulumi.set(__self__, "mirror_id", mirror_id)
        if mirror_overwrites_diverged_branches is not None:
            pulumi.set(__self__, "mirror_overwrites_diverged_branches", mirror_overwrites_diverged_branches)
        if mirror_trigger_builds is not None:
            pulumi.set(__self__, "mirror_trigger_builds", mirror_trigger_builds)
        if only_mirror_protected_branches is not None:
            pulumi.set(__self__, "only_mirror_protected_branches", only_mirror_protected_branches)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if update_status is not None:
            pulumi.set(__self__, "update_status", update_status)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="authPassword")
    def auth_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authentication password or token for the remote repository.
        """
        return pulumi.get(self, "auth_password")

    @auth_password.setter
    def auth_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_password", value)

    @_builtins.property
    @pulumi.getter(name="authUser")
    def auth_user(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authentication username for the remote repository.
        """
        return pulumi.get(self, "auth_user")

    @auth_user.setter
    def auth_user(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_user", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable the pull mirror. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="lastError")
    def last_error(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Last error message from the mirror operation.
        """
        return pulumi.get(self, "last_error")

    @last_error.setter
    def last_error(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_error", value)

    @_builtins.property
    @pulumi.getter(name="lastSuccessfulUpdateAt")
    def last_successful_update_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp of the last successful mirror update.
        """
        return pulumi.get(self, "last_successful_update_at")

    @last_successful_update_at.setter
    def last_successful_update_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_successful_update_at", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdateAt")
    def last_update_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp of the last mirror update attempt.
        """
        return pulumi.get(self, "last_update_at")

    @last_update_at.setter
    def last_update_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_update_at", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdateStartedAt")
    def last_update_started_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp when the last mirror update started.
        """
        return pulumi.get(self, "last_update_started_at")

    @last_update_started_at.setter
    def last_update_started_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_update_started_at", value)

    @_builtins.property
    @pulumi.getter(name="mirrorBranchRegex")
    def mirror_branch_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Regular expression for branches to mirror. Requires GitLab Premium or Ultimate. Cannot be used with `only_mirror_protected_branches`.
        """
        return pulumi.get(self, "mirror_branch_regex")

    @mirror_branch_regex.setter
    def mirror_branch_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mirror_branch_regex", value)

    @_builtins.property
    @pulumi.getter(name="mirrorId")
    def mirror_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the pull mirror. This ID is set by GitLab.
        """
        return pulumi.get(self, "mirror_id")

    @mirror_id.setter
    def mirror_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mirror_id", value)

    @_builtins.property
    @pulumi.getter(name="mirrorOverwritesDivergedBranches")
    def mirror_overwrites_diverged_branches(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Overwrite diverged branches on the target project.
        """
        return pulumi.get(self, "mirror_overwrites_diverged_branches")

    @mirror_overwrites_diverged_branches.setter
    def mirror_overwrites_diverged_branches(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mirror_overwrites_diverged_branches", value)

    @_builtins.property
    @pulumi.getter(name="mirrorTriggerBuilds")
    def mirror_trigger_builds(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Trigger CI/CD pipelines when the mirror updates.
        """
        return pulumi.get(self, "mirror_trigger_builds")

    @mirror_trigger_builds.setter
    def mirror_trigger_builds(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mirror_trigger_builds", value)

    @_builtins.property
    @pulumi.getter(name="onlyMirrorProtectedBranches")
    def only_mirror_protected_branches(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Mirror only protected branches. Cannot be used with `mirror_branch_regex`.
        """
        return pulumi.get(self, "only_mirror_protected_branches")

    @only_mirror_protected_branches.setter
    def only_mirror_protected_branches(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "only_mirror_protected_branches", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="updateStatus")
    def update_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Current status of the mirror update.
        """
        return pulumi.get(self, "update_status")

    @update_status.setter
    def update_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_status", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the remote repository to mirror from. While the API call allows including username and password as basic authentication in the URL, this resourcedoes not for security and idempotency reasons. Use `auth_user` and `auth_password` instead.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("gitlab:index/projectPullMirror:ProjectPullMirror")
class ProjectPullMirror(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_password: Optional[pulumi.Input[_builtins.str]] = None,
                 auth_user: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror_overwrites_diverged_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_trigger_builds: Optional[pulumi.Input[_builtins.bool]] = None,
                 only_mirror_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectPullMirror` resource allows managing pull mirroring for GitLab projects.

        This resource uses the dedicated pull mirror API endpoint which provides reliable configuration of pull mirroring after project creation.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_pull_mirroring/#configure-pull-mirroring-for-a-project)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # Basic pull mirror from GitHub
        # Note: Unspecified options will use GitLab's defaults
        github = gitlab.ProjectPullMirror("github",
            project=example["id"],
            url="https://github.com/example/repo.git",
            auth_user="github-username",
            auth_password=github_token)
        # Pull mirror with explicit options
        # Only specify options you want to control; omit others to use GitLab defaults
        advanced = gitlab.ProjectPullMirror("advanced",
            project=example["id"],
            url="https://github.com/example/repo.git",
            enabled=True,
            auth_user="github-username",
            auth_password=github_token,
            mirror_trigger_builds=True,
            only_mirror_protected_branches=True,
            mirror_overwrites_diverged_branches=False)
        # Pull mirror with branch regex (Premium/Ultimate)
        regex = gitlab.ProjectPullMirror("regex",
            project=example["id"],
            url="https://github.com/example/repo.git",
            auth_user="github-username",
            auth_password=github_token,
            mirror_branch_regex="^(main|develop|release/.*)$")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_pull_mirror`. For example:

        terraform

        import {

          to = gitlab_project_pull_mirror.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Import using project ID

        ```sh
        $ pulumi import gitlab:index/projectPullMirror:ProjectPullMirror example 123
        ```

        Import using project path

        Note: Import is not supported for disabled mirrors because the GitLab API returns

        http 400 for disabled mirrors.

        ```sh
        $ pulumi import gitlab:index/projectPullMirror:ProjectPullMirror example "group/project"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_password: Authentication password or token for the remote repository.
        :param pulumi.Input[_builtins.str] auth_user: Authentication username for the remote repository.
        :param pulumi.Input[_builtins.bool] enabled: Enable or disable the pull mirror. Defaults to `true`.
        :param pulumi.Input[_builtins.str] mirror_branch_regex: Regular expression for branches to mirror. Requires GitLab Premium or Ultimate. Cannot be used with `only_mirror_protected_branches`.
        :param pulumi.Input[_builtins.bool] mirror_overwrites_diverged_branches: Overwrite diverged branches on the target project.
        :param pulumi.Input[_builtins.bool] mirror_trigger_builds: Trigger CI/CD pipelines when the mirror updates.
        :param pulumi.Input[_builtins.bool] only_mirror_protected_branches: Mirror only protected branches. Cannot be used with `mirror_branch_regex`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project owned by the authenticated user.
        :param pulumi.Input[_builtins.str] url: The URL of the remote repository to mirror from. While the API call allows including username and password as basic authentication in the URL, this resourcedoes not for security and idempotency reasons. Use `auth_user` and `auth_password` instead.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectPullMirrorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectPullMirror` resource allows managing pull mirroring for GitLab projects.

        This resource uses the dedicated pull mirror API endpoint which provides reliable configuration of pull mirroring after project creation.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_pull_mirroring/#configure-pull-mirroring-for-a-project)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # Basic pull mirror from GitHub
        # Note: Unspecified options will use GitLab's defaults
        github = gitlab.ProjectPullMirror("github",
            project=example["id"],
            url="https://github.com/example/repo.git",
            auth_user="github-username",
            auth_password=github_token)
        # Pull mirror with explicit options
        # Only specify options you want to control; omit others to use GitLab defaults
        advanced = gitlab.ProjectPullMirror("advanced",
            project=example["id"],
            url="https://github.com/example/repo.git",
            enabled=True,
            auth_user="github-username",
            auth_password=github_token,
            mirror_trigger_builds=True,
            only_mirror_protected_branches=True,
            mirror_overwrites_diverged_branches=False)
        # Pull mirror with branch regex (Premium/Ultimate)
        regex = gitlab.ProjectPullMirror("regex",
            project=example["id"],
            url="https://github.com/example/repo.git",
            auth_user="github-username",
            auth_password=github_token,
            mirror_branch_regex="^(main|develop|release/.*)$")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_pull_mirror`. For example:

        terraform

        import {

          to = gitlab_project_pull_mirror.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Import using project ID

        ```sh
        $ pulumi import gitlab:index/projectPullMirror:ProjectPullMirror example 123
        ```

        Import using project path

        Note: Import is not supported for disabled mirrors because the GitLab API returns

        http 400 for disabled mirrors.

        ```sh
        $ pulumi import gitlab:index/projectPullMirror:ProjectPullMirror example "group/project"
        ```

        :param str resource_name: The name of the resource.
        :param ProjectPullMirrorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectPullMirrorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_password: Optional[pulumi.Input[_builtins.str]] = None,
                 auth_user: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror_overwrites_diverged_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_trigger_builds: Optional[pulumi.Input[_builtins.bool]] = None,
                 only_mirror_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectPullMirrorArgs.__new__(ProjectPullMirrorArgs)

            __props__.__dict__["auth_password"] = None if auth_password is None else pulumi.Output.secret(auth_password)
            __props__.__dict__["auth_user"] = auth_user
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["mirror_branch_regex"] = mirror_branch_regex
            __props__.__dict__["mirror_overwrites_diverged_branches"] = mirror_overwrites_diverged_branches
            __props__.__dict__["mirror_trigger_builds"] = mirror_trigger_builds
            __props__.__dict__["only_mirror_protected_branches"] = only_mirror_protected_branches
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = None if url is None else pulumi.Output.secret(url)
            __props__.__dict__["last_error"] = None
            __props__.__dict__["last_successful_update_at"] = None
            __props__.__dict__["last_update_at"] = None
            __props__.__dict__["last_update_started_at"] = None
            __props__.__dict__["mirror_id"] = None
            __props__.__dict__["update_status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["authPassword", "url"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectPullMirror, __self__).__init__(
            'gitlab:index/projectPullMirror:ProjectPullMirror',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_password: Optional[pulumi.Input[_builtins.str]] = None,
            auth_user: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            last_error: Optional[pulumi.Input[_builtins.str]] = None,
            last_successful_update_at: Optional[pulumi.Input[_builtins.str]] = None,
            last_update_at: Optional[pulumi.Input[_builtins.str]] = None,
            last_update_started_at: Optional[pulumi.Input[_builtins.str]] = None,
            mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
            mirror_id: Optional[pulumi.Input[_builtins.int]] = None,
            mirror_overwrites_diverged_branches: Optional[pulumi.Input[_builtins.bool]] = None,
            mirror_trigger_builds: Optional[pulumi.Input[_builtins.bool]] = None,
            only_mirror_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            update_status: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectPullMirror':
        """
        Get an existing ProjectPullMirror resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_password: Authentication password or token for the remote repository.
        :param pulumi.Input[_builtins.str] auth_user: Authentication username for the remote repository.
        :param pulumi.Input[_builtins.bool] enabled: Enable or disable the pull mirror. Defaults to `true`.
        :param pulumi.Input[_builtins.str] last_error: Last error message from the mirror operation.
        :param pulumi.Input[_builtins.str] last_successful_update_at: Timestamp of the last successful mirror update.
        :param pulumi.Input[_builtins.str] last_update_at: Timestamp of the last mirror update attempt.
        :param pulumi.Input[_builtins.str] last_update_started_at: Timestamp when the last mirror update started.
        :param pulumi.Input[_builtins.str] mirror_branch_regex: Regular expression for branches to mirror. Requires GitLab Premium or Ultimate. Cannot be used with `only_mirror_protected_branches`.
        :param pulumi.Input[_builtins.int] mirror_id: The ID of the pull mirror. This ID is set by GitLab.
        :param pulumi.Input[_builtins.bool] mirror_overwrites_diverged_branches: Overwrite diverged branches on the target project.
        :param pulumi.Input[_builtins.bool] mirror_trigger_builds: Trigger CI/CD pipelines when the mirror updates.
        :param pulumi.Input[_builtins.bool] only_mirror_protected_branches: Mirror only protected branches. Cannot be used with `mirror_branch_regex`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project owned by the authenticated user.
        :param pulumi.Input[_builtins.str] update_status: Current status of the mirror update.
        :param pulumi.Input[_builtins.str] url: The URL of the remote repository to mirror from. While the API call allows including username and password as basic authentication in the URL, this resourcedoes not for security and idempotency reasons. Use `auth_user` and `auth_password` instead.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectPullMirrorState.__new__(_ProjectPullMirrorState)

        __props__.__dict__["auth_password"] = auth_password
        __props__.__dict__["auth_user"] = auth_user
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["last_error"] = last_error
        __props__.__dict__["last_successful_update_at"] = last_successful_update_at
        __props__.__dict__["last_update_at"] = last_update_at
        __props__.__dict__["last_update_started_at"] = last_update_started_at
        __props__.__dict__["mirror_branch_regex"] = mirror_branch_regex
        __props__.__dict__["mirror_id"] = mirror_id
        __props__.__dict__["mirror_overwrites_diverged_branches"] = mirror_overwrites_diverged_branches
        __props__.__dict__["mirror_trigger_builds"] = mirror_trigger_builds
        __props__.__dict__["only_mirror_protected_branches"] = only_mirror_protected_branches
        __props__.__dict__["project"] = project
        __props__.__dict__["update_status"] = update_status
        __props__.__dict__["url"] = url
        return ProjectPullMirror(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authPassword")
    def auth_password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Authentication password or token for the remote repository.
        """
        return pulumi.get(self, "auth_password")

    @_builtins.property
    @pulumi.getter(name="authUser")
    def auth_user(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Authentication username for the remote repository.
        """
        return pulumi.get(self, "auth_user")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable or disable the pull mirror. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="lastError")
    def last_error(self) -> pulumi.Output[_builtins.str]:
        """
        Last error message from the mirror operation.
        """
        return pulumi.get(self, "last_error")

    @_builtins.property
    @pulumi.getter(name="lastSuccessfulUpdateAt")
    def last_successful_update_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp of the last successful mirror update.
        """
        return pulumi.get(self, "last_successful_update_at")

    @_builtins.property
    @pulumi.getter(name="lastUpdateAt")
    def last_update_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp of the last mirror update attempt.
        """
        return pulumi.get(self, "last_update_at")

    @_builtins.property
    @pulumi.getter(name="lastUpdateStartedAt")
    def last_update_started_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp when the last mirror update started.
        """
        return pulumi.get(self, "last_update_started_at")

    @_builtins.property
    @pulumi.getter(name="mirrorBranchRegex")
    def mirror_branch_regex(self) -> pulumi.Output[_builtins.str]:
        """
        Regular expression for branches to mirror. Requires GitLab Premium or Ultimate. Cannot be used with `only_mirror_protected_branches`.
        """
        return pulumi.get(self, "mirror_branch_regex")

    @_builtins.property
    @pulumi.getter(name="mirrorId")
    def mirror_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of the pull mirror. This ID is set by GitLab.
        """
        return pulumi.get(self, "mirror_id")

    @_builtins.property
    @pulumi.getter(name="mirrorOverwritesDivergedBranches")
    def mirror_overwrites_diverged_branches(self) -> pulumi.Output[_builtins.bool]:
        """
        Overwrite diverged branches on the target project.
        """
        return pulumi.get(self, "mirror_overwrites_diverged_branches")

    @_builtins.property
    @pulumi.getter(name="mirrorTriggerBuilds")
    def mirror_trigger_builds(self) -> pulumi.Output[_builtins.bool]:
        """
        Trigger CI/CD pipelines when the mirror updates.
        """
        return pulumi.get(self, "mirror_trigger_builds")

    @_builtins.property
    @pulumi.getter(name="onlyMirrorProtectedBranches")
    def only_mirror_protected_branches(self) -> pulumi.Output[_builtins.bool]:
        """
        Mirror only protected branches. Cannot be used with `mirror_branch_regex`.
        """
        return pulumi.get(self, "only_mirror_protected_branches")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="updateStatus")
    def update_status(self) -> pulumi.Output[_builtins.str]:
        """
        Current status of the mirror update.
        """
        return pulumi.get(self, "update_status")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the remote repository to mirror from. While the API call allows including username and password as basic authentication in the URL, this resourcedoes not for security and idempotency reasons. Use `auth_user` and `auth_password` instead.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectSecureFileArgs', 'ProjectSecureFile']

@pulumi.input_type
class ProjectSecureFileArgs:
    def __init__(__self__, *,
                 content: pulumi.Input[_builtins.str],
                 project: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProjectSecureFile resource.
        :param pulumi.Input[_builtins.str] content: The contents of the secure file
        :param pulumi.Input[_builtins.str] project: The ID or full path of the project to environment is created for.
        :param pulumi.Input[_builtins.str] name: The name for the secure file, unique per project
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "project", project)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def content(self) -> pulumi.Input[_builtins.str]:
        """
        The contents of the secure file
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "content", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or full path of the project to environment is created for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the secure file, unique per project
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ProjectSecureFileState:
    def __init__(__self__, *,
                 checksum: Optional[pulumi.Input[_builtins.str]] = None,
                 checksum_algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 secure_file_id: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering ProjectSecureFile resources.
        :param pulumi.Input[_builtins.str] checksum: The checksum of the file
        :param pulumi.Input[_builtins.str] checksum_algorithm: The checksum algorithm used
        :param pulumi.Input[_builtins.str] content: The contents of the secure file
        :param pulumi.Input[_builtins.str] created_at: The time the secure file was uploaded
        :param pulumi.Input[_builtins.str] expires_at: The time the secure file will expire
        :param pulumi.Input[_builtins.str] name: The name for the secure file, unique per project
        :param pulumi.Input[_builtins.str] project: The ID or full path of the project to environment is created for.
        :param pulumi.Input[_builtins.int] secure_file_id: The id of the secure file in gitlab
        """
        if checksum is not None:
            pulumi.set(__self__, "checksum", checksum)
        if checksum_algorithm is not None:
            pulumi.set(__self__, "checksum_algorithm", checksum_algorithm)
        if content is not None:
            pulumi.set(__self__, "content", content)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if secure_file_id is not None:
            pulumi.set(__self__, "secure_file_id", secure_file_id)

    @_builtins.property
    @pulumi.getter
    def checksum(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The checksum of the file
        """
        return pulumi.get(self, "checksum")

    @checksum.setter
    def checksum(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "checksum", value)

    @_builtins.property
    @pulumi.getter(name="checksumAlgorithm")
    def checksum_algorithm(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The checksum algorithm used
        """
        return pulumi.get(self, "checksum_algorithm")

    @checksum_algorithm.setter
    def checksum_algorithm(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "checksum_algorithm", value)

    @_builtins.property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contents of the secure file
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "content", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The time the secure file was uploaded
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The time the secure file will expire
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the secure file, unique per project
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or full path of the project to environment is created for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="secureFileId")
    def secure_file_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The id of the secure file in gitlab
        """
        return pulumi.get(self, "secure_file_id")

    @secure_file_id.setter
    def secure_file_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "secure_file_id", value)


@pulumi.type_token("gitlab:index/projectSecureFile:ProjectSecureFile")
class ProjectSecureFile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectSecureFile` resource allows users to manage the lifecycle of a secure file in gitlab.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/secure_files/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab
        import pulumi_std as std

        this = gitlab.Group("this",
            name="example",
            path="example",
            description="An example group")
        this_project = gitlab.Project("this",
            name="example",
            namespace_id=this.id,
            initialize_with_readme=True)
        this_project_secure_file = gitlab.ProjectSecureFile("this",
            name="my-secure-file",
            project=this_project.id,
            content=std.file(input="example.txt").result)
        disable_poll_for_metadata = gitlab.ProjectSecureFile("disable_poll_for_metadata",
            name="my-secure-file",
            project=this_project.id,
            content=std.file(input="example.txt").result,
            poll_for_metadata_duration_in_seconds=0)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_secure_file`. For example:

        terraform

        import {

          to = gitlab_project_secure_file.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab secure files can be imported using an id made up of `projectId:secureFileId`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectSecureFile:ProjectSecureFile bar 123:321
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] content: The contents of the secure file
        :param pulumi.Input[_builtins.str] name: The name for the secure file, unique per project
        :param pulumi.Input[_builtins.str] project: The ID or full path of the project to environment is created for.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectSecureFileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectSecureFile` resource allows users to manage the lifecycle of a secure file in gitlab.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/secure_files/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab
        import pulumi_std as std

        this = gitlab.Group("this",
            name="example",
            path="example",
            description="An example group")
        this_project = gitlab.Project("this",
            name="example",
            namespace_id=this.id,
            initialize_with_readme=True)
        this_project_secure_file = gitlab.ProjectSecureFile("this",
            name="my-secure-file",
            project=this_project.id,
            content=std.file(input="example.txt").result)
        disable_poll_for_metadata = gitlab.ProjectSecureFile("disable_poll_for_metadata",
            name="my-secure-file",
            project=this_project.id,
            content=std.file(input="example.txt").result,
            poll_for_metadata_duration_in_seconds=0)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_secure_file`. For example:

        terraform

        import {

          to = gitlab_project_secure_file.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab secure files can be imported using an id made up of `projectId:secureFileId`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectSecureFile:ProjectSecureFile bar 123:321
        ```

        :param str resource_name: The name of the resource.
        :param ProjectSecureFileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectSecureFileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectSecureFileArgs.__new__(ProjectSecureFileArgs)

            if content is None and not opts.urn:
                raise TypeError("Missing required property 'content'")
            __props__.__dict__["content"] = None if content is None else pulumi.Output.secret(content)
            __props__.__dict__["name"] = name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["checksum"] = None
            __props__.__dict__["checksum_algorithm"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["expires_at"] = None
            __props__.__dict__["secure_file_id"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["content"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectSecureFile, __self__).__init__(
            'gitlab:index/projectSecureFile:ProjectSecureFile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            checksum: Optional[pulumi.Input[_builtins.str]] = None,
            checksum_algorithm: Optional[pulumi.Input[_builtins.str]] = None,
            content: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            expires_at: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            secure_file_id: Optional[pulumi.Input[_builtins.int]] = None) -> 'ProjectSecureFile':
        """
        Get an existing ProjectSecureFile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] checksum: The checksum of the file
        :param pulumi.Input[_builtins.str] checksum_algorithm: The checksum algorithm used
        :param pulumi.Input[_builtins.str] content: The contents of the secure file
        :param pulumi.Input[_builtins.str] created_at: The time the secure file was uploaded
        :param pulumi.Input[_builtins.str] expires_at: The time the secure file will expire
        :param pulumi.Input[_builtins.str] name: The name for the secure file, unique per project
        :param pulumi.Input[_builtins.str] project: The ID or full path of the project to environment is created for.
        :param pulumi.Input[_builtins.int] secure_file_id: The id of the secure file in gitlab
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectSecureFileState.__new__(_ProjectSecureFileState)

        __props__.__dict__["checksum"] = checksum
        __props__.__dict__["checksum_algorithm"] = checksum_algorithm
        __props__.__dict__["content"] = content
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["secure_file_id"] = secure_file_id
        return ProjectSecureFile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def checksum(self) -> pulumi.Output[_builtins.str]:
        """
        The checksum of the file
        """
        return pulumi.get(self, "checksum")

    @_builtins.property
    @pulumi.getter(name="checksumAlgorithm")
    def checksum_algorithm(self) -> pulumi.Output[_builtins.str]:
        """
        The checksum algorithm used
        """
        return pulumi.get(self, "checksum_algorithm")

    @_builtins.property
    @pulumi.getter
    def content(self) -> pulumi.Output[_builtins.str]:
        """
        The contents of the secure file
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The time the secure file was uploaded
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[_builtins.str]:
        """
        The time the secure file will expire
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name for the secure file, unique per project
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or full path of the project to environment is created for.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="secureFileId")
    def secure_file_id(self) -> pulumi.Output[_builtins.int]:
        """
        The id of the secure file in gitlab
        """
        return pulumi.get(self, "secure_file_id")

